==> org.eclipse.wb.core.databinding.xsd.source_1.0.0.202401190510.jar: org/eclipse/wb/core/databinding/xsd/component/MethodParameter.java <==

package org.eclipse.wb.core.databinding.xsd.component;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MethodParameter complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MethodParameter"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="editor" type="{http://www.eclipse.org/wb/WBPComponent}PropertyEditor" minOccurs="0"/&gt;
 *         &lt;element name="tag" type="{http://www.eclipse.org/wb/WBPComponent}TagType" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="type" use="required" type="{http://www.eclipse.org/wb/WBPComponent}ClassName" /&gt;
 *       &lt;attribute name="parent" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="child" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="parent2" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="child2" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="defaultSource" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="property" type="{http://www.eclipse.org/wb/WBPComponent}PropertyId" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MethodParameter", namespace = "http://www.eclipse.org/wb/WBPComponent", propOrder = {
    "editor",
    "tag"
})
public class MethodParameter {

    @XmlElement(namespace = "http://www.eclipse.org/wb/WBPComponent")
    protected PropertyEditor editor;
    @XmlElement(namespace = "http://www.eclipse.org/wb/WBPComponent")
    protected List<TagType> tag;
    @XmlAttribute(name = "type", required = true)
    protected String type;
    @XmlAttribute(name = "parent")
    protected Boolean parent;
    @XmlAttribute(name = "child")
    protected Boolean child;
    @XmlAttribute(name = "parent2")
    protected Boolean parent2;
    @XmlAttribute(name = "child2")
    protected Boolean child2;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "defaultSource")
    protected String defaultSource;
    @XmlAttribute(name = "property")
    protected String property;

    /**
     * Gets the value of the editor property.
     * 
     * @return
     *     possible object is
     *     {@link PropertyEditor }
     *     
     */
    public PropertyEditor getEditor() {
        return editor;
    }

    /**
     * Sets the value of the editor property.
     * 
     * @param value
     *     allowed object is
     *     {@link PropertyEditor }
     *     
     */
    public void setEditor(PropertyEditor value) {
        this.editor = value;
    }

    /**
     * Gets the value of the tag property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a <CODE>set</CODE> method for the tag property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTag().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TagType }
     * 
     * 
     */
    public List<TagType> getTag() {
        if (tag == null) {
            tag = new ArrayList<TagType>();
        }
        return this.tag;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Gets the value of the parent property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isParent() {
        return parent;
    }

    /**
     * Sets the value of the parent property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setParent(Boolean value) {
        this.parent = value;
    }

    /**
     * Gets the value of the child property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isChild() {
        return child;
    }

    /**
     * Sets the value of the child property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setChild(Boolean value) {
        this.child = value;
    }

    /**
     * Gets the value of the parent2 property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isParent2() {
        return parent2;
    }

    /**
     * Sets the value of the parent2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setParent2(Boolean value) {
        this.parent2 = value;
    }

    /**
     * Gets the value of the child2 property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isChild2() {
        return child2;
    }

    /**
     * Sets the value of the child2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setChild2(Boolean value) {
        this.child2 = value;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the defaultSource property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDefaultSource() {
        return defaultSource;
    }

    /**
     * Sets the value of the defaultSource property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDefaultSource(String value) {
        this.defaultSource = value;
    }

    /**
     * Gets the value of the property property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getProperty() {
        return property;
    }

    /**
     * Sets the value of the property property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setProperty(String value) {
        this.property = value;
    }

}

==> org.eclipse.wb.core.databinding.xsd.source_1.1.0.202601140522.jar: org/eclipse/wb/core/databinding/xsd/component/MethodParameter.java <==

package org.eclipse.wb.core.databinding.xsd.component;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MethodParameter complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="MethodParameter">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="editor" type="{http://www.eclipse.org/wb/WBPComponent}PropertyEditor" minOccurs="0"/>
 *         <element name="tag" type="{http://www.eclipse.org/wb/WBPComponent}TagType" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="type" use="required" type="{http://www.eclipse.org/wb/WBPComponent}ClassName" />
 *       <attribute name="parent" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="child" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="parent2" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="child2" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="defaultSource" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="property" type="{http://www.eclipse.org/wb/WBPComponent}PropertyId" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MethodParameter", namespace = "http://www.eclipse.org/wb/WBPComponent", propOrder = {
    "editor",
    "tag"
})
public class MethodParameter {

    @XmlElement(namespace = "http://www.eclipse.org/wb/WBPComponent")
    protected PropertyEditor editor;
    @XmlElement(namespace = "http://www.eclipse.org/wb/WBPComponent")
    protected List<TagType> tag;
    @XmlAttribute(name = "type", required = true)
    protected String type;
    @XmlAttribute(name = "parent")
    protected Boolean parent;
    @XmlAttribute(name = "child")
    protected Boolean child;
    @XmlAttribute(name = "parent2")
    protected Boolean parent2;
    @XmlAttribute(name = "child2")
    protected Boolean child2;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "defaultSource")
    protected String defaultSource;
    @XmlAttribute(name = "property")
    protected String property;

    /**
     * Gets the value of the editor property.
     * 
     * @return
     *     possible object is
     *     {@link PropertyEditor }
     *     
     */
    public PropertyEditor getEditor() {
        return editor;
    }

    /**
     * Sets the value of the editor property.
     * 
     * @param value
     *     allowed object is
     *     {@link PropertyEditor }
     *     
     */
    public void setEditor(PropertyEditor value) {
        this.editor = value;
    }

    /**
     * Gets the value of the tag property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tag property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getTag().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TagType }
     * </p>
     * 
     * 
     * @return
     *     The value of the tag property.
     */
    public List<TagType> getTag() {
        if (tag == null) {
            tag = new ArrayList<>();
        }
        return this.tag;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Gets the value of the parent property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isParent() {
        return parent;
    }

    /**
     * Sets the value of the parent property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setParent(Boolean value) {
        this.parent = value;
    }

    /**
     * Gets the value of the child property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isChild() {
        return child;
    }

    /**
     * Sets the value of the child property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setChild(Boolean value) {
        this.child = value;
    }

    /**
     * Gets the value of the parent2 property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isParent2() {
        return parent2;
    }

    /**
     * Sets the value of the parent2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setParent2(Boolean value) {
        this.parent2 = value;
    }

    /**
     * Gets the value of the child2 property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isChild2() {
        return child2;
    }

    /**
     * Sets the value of the child2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setChild2(Boolean value) {
        this.child2 = value;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the defaultSource property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDefaultSource() {
        return defaultSource;
    }

    /**
     * Sets the value of the defaultSource property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDefaultSource(String value) {
        this.defaultSource = value;
    }

    /**
     * Gets the value of the property property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getProperty() {
        return property;
    }

    /**
     * Sets the value of the property property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setProperty(String value) {
        this.property = value;
    }

}
